import os
import sys
import platform

class PathConfig:
    def __init__(self):
        self.is_frozen = getattr(sys, 'frozen', False)
        self.is_macos = platform.system() == 'Darwin'
        
        # 设置基础路径
        if self.is_frozen:
            if self.is_macos:
                # macOS 打包后的路径
                self.base_path = os.path.dirname(sys.executable)
                self.resources_path = os.path.join(self.base_path, 'Resources')
            else:
                # 其他系统的打包路径
                self.base_path = os.path.dirname(sys.executable)
                self.resources_path = self.base_path
        else:
            # 开发环境路径
            self.base_path = os.path.dirname(os.path.abspath(__file__))
            self.resources_path = self.base_path
        
        # 设置资源文件路径
        self.assets_path = os.path.join(self.resources_path, 'assets')
        self.icons_path = os.path.join(self.assets_path, 'icons')
        
        # 确保必要的目录存在
        self._ensure_directories()
    
    def _ensure_directories(self):
        """确保必要的目录存在"""
        directories = [
            self.assets_path,
            self.icons_path,
        ]
        for directory in directories:
            os.makedirs(directory, exist_ok=True)
    
    def get_resource_path(self, relative_path):
        """获取资源文件的绝对路径"""
        return os.path.join(self.resources_path, relative_path)
    
    def get_icon_path(self, icon_name):
        """获取图标文件的绝对路径"""
        return os.path.join(self.icons_path, icon_name)

# 创建全局配置实例
config = PathConfig()
