from .essentia_detector import EssentiaDetector
from .librosa_detector import LibrosaDetector
from .madmom_detector import MadmomDetector

class DetectorFactory:
    @staticmethod
    def create_detector(detector_type, audio_path=None):
        """
        创建检测器实例
        :param detector_type: 检测器类型 ('essentia', 'librosa' 或 'madmom')
        :param audio_path: 音频文件路径
        :return: 检测器实例
        """
        if detector_type == 'essentia':
            return EssentiaDetector(audio_path)
        elif detector_type == 'librosa':
            return LibrosaDetector(audio_path)
        elif detector_type == 'madmom':
            return MadmomDetector(audio_path)
        else:
            raise ValueError(f"不支持的检测器类型: {detector_type}")

    @staticmethod
    def get_available_detectors():
        """获取所有可用的检测器类型"""
        return ['essentia', 'librosa', 'madmom']
